package net.sf.javaprinciples.web;

import java.io.PrintWriter;
import java.io.StringWriter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.ws.soap.server.endpoint.AbstractSoapFaultDefinitionExceptionResolver;
import org.springframework.ws.soap.server.endpoint.SoapFaultDefinition;

/**
 * Handle all exceptions.
 * 1. Log
 * 2. Added the stack trace to soap fault
 *
 * @author Warwick Slade
 */
public class ExceptionResolver extends AbstractSoapFaultDefinitionExceptionResolver
{
    private static final Logger LOGGER = LoggerFactory.getLogger(ExceptionResolver.class);

    @Override
    protected SoapFaultDefinition getFaultDefinition(Object endpoint, Exception ex)
    {
        LOGGER.error(ex.getMessage(), ex);

        StringWriter stringWriter = new StringWriter();
        PrintWriter writer = new PrintWriter(stringWriter);
        ex.printStackTrace(writer);

        SoapFaultDefinition defn = new SoapFaultDefinition();

        defn.setFaultCode(SoapFaultDefinition.SERVER);
        defn.setFaultStringOrReason(stringWriter.toString());
        return defn;
    }
}
